PCB Environment: NavSpacings Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
NavSpacings Struct Reference

This struct stores the spacing requirements the NavGrid is/should be prepared for. More...

`#include <NavGrid.hpp>`

## Public Member Functions
| NavSpacings (const Connection &)
bool | initialized () const
bool | operator== (const NavSpacings &that) const
Real | getExpansionForTracks (Real clearance) const
| @clearance is the clearance required by the obstacle, this.Clearance is that required by the track.
Real | getExpansionForVias (Real clarance) const

## Data Fields
Real | Clearance
Real | TrackWidthHalf
Real | ViaRadius

## Detailed Description

This struct stores the spacing requirements the NavGrid is/should be prepared for.

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavGrid.hpp